"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var TNSWebGLRenderingContext_1 = require("./TNSWebGLRenderingContext");
var canvas_plugin_common_1 = require("./canvas-plugin.common");
var TNSImageAsset_1 = require("./TNSImageAsset");
var image_source_1 = require("tns-core-modules/image-source/image-source");
var TNSWebGL2RenderingContext = (function (_super) {
    __extends(TNSWebGL2RenderingContext, _super);
    function TNSWebGL2RenderingContext(context) {
        return _super.call(this, context) || this;
    }
    TNSWebGL2RenderingContext.prototype._glCheckError = function (message) {
        if (!TNSWebGL2RenderingContext.isDebug) {
            return;
        }
        console.log(message, this.getError());
    };
    TNSWebGL2RenderingContext.prototype.beginQuery = function (target, query) {
        this._glCheckError('beginQuery');
        var value = query ? query.native : 0;
        this.native.beginQuery(target, value);
    };
    TNSWebGL2RenderingContext.prototype.beginTransformFeedback = function (primitiveMode) {
        this._glCheckError('beginTransformFeedback');
        this.native.beginTransformFeedback(primitiveMode);
    };
    TNSWebGL2RenderingContext.prototype.bindBufferBase = function (target, index, buffer) {
        this._glCheckError('bindBufferBase');
        var value = buffer ? buffer.native : 0;
        this.native.bindBufferBase(target, index, value);
    };
    TNSWebGL2RenderingContext.prototype.bindBufferRange = function (target, index, buffer, offset, size) {
        this._glCheckError('bindBufferRange');
        var value = buffer ? buffer.native : 0;
        this.native.bindBufferRange(target, index, value, offset, size);
    };
    TNSWebGL2RenderingContext.prototype.bindSampler = function (unit, sampler) {
        this._glCheckError('bindSampler');
        var value = sampler ? sampler.native : 0;
        this.native.bindSampler(unit, value);
    };
    TNSWebGL2RenderingContext.prototype.bindTransformFeedback = function (target, transformFeedback) {
        this._glCheckError('bindTransformFeedback');
        var value = transformFeedback ? transformFeedback.native : 0;
        this.native.bindTransformFeedback(target, value);
    };
    TNSWebGL2RenderingContext.prototype.bindVertexArray = function (vertexArray) {
        this._glCheckError('bindVertexArray');
        var value = vertexArray ? vertexArray.native : 0;
        this.native.bindVertexArray(value);
    };
    TNSWebGL2RenderingContext.prototype.blitFramebuffer = function (srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter) {
        this._glCheckError('blitFramebuffer');
        this.native.blitFramebuffer(srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter);
    };
    TNSWebGL2RenderingContext.prototype.clearBufferfi = function (buffer, drawbuffer, depth, stencil) {
        this._glCheckError('clearBufferfi');
        var value = buffer ? buffer.native : 0;
        this.native.clearBufferfi(value, drawbuffer, depth, stencil);
    };
    TNSWebGL2RenderingContext.prototype.clearBufferfv = function (buffer, drawbuffer, values) {
        this._glCheckError('clearBufferfv');
        var value = buffer ? buffer.native : 0;
        if (values instanceof Float32Array) {
            values = this.toNativeArray(values, 'float');
        }
        this.native.clearBufferfv(value, drawbuffer, values);
    };
    TNSWebGL2RenderingContext.prototype.clearBufferiv = function (buffer, drawbuffer, values) {
        this._glCheckError('clearBufferiv');
        var value = buffer ? buffer.native : 0;
        if (values instanceof Int32Array) {
            values = this.toNativeArray(values, 'int');
        }
        this.native.clearBufferiv(value, drawbuffer, values);
    };
    TNSWebGL2RenderingContext.prototype.clearBufferuiv = function (buffer, drawbuffer, values) {
        this._glCheckError('clearBufferuiv');
        var value = buffer ? buffer.native : 0;
        if (values instanceof Uint32Array) {
            values = this.toNativeArray(values, 'int');
        }
        this.native.clearBufferuiv(value, drawbuffer, values);
    };
    TNSWebGL2RenderingContext.prototype.clientWaitSync = function (sync, flags, timeout) {
        this._glCheckError('clientWaitSync');
        var value = sync ? sync.native : 0;
        return this.native.clientWaitSync(value, flags, timeout);
    };
    TNSWebGL2RenderingContext.prototype.compressedTexSubImage3D = function (target, level, xoffset, yoffset, zoffset, width, height, depth, format, srcData, srcOffset, srcLengthOverride) {
        if (srcOffset === void 0) { srcOffset = 0; }
        if (srcLengthOverride === void 0) { srcLengthOverride = 0; }
        this._glCheckError('compressedTexSubImage3D');
        if (typeof srcOffset === 'number') {
            this.native.compressedTexSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, srcData, srcOffset);
        }
        else if (srcData && srcData.buffer) {
            if (srcData instanceof Uint8Array) {
                this.native.compressedTexSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, this.toNativeArray(srcData, 'byte'), srcOffset, srcLengthOverride);
            }
        }
    };
    TNSWebGL2RenderingContext.prototype.copyBufferSubData = function (readTarget, writeTarget, readOffset, writeOffset, size) {
        this._glCheckError('copyBufferSubData');
        this.native.copyBufferSubData(readTarget, writeTarget, readOffset, writeOffset, size);
    };
    TNSWebGL2RenderingContext.prototype.copyTexSubImage3D = function (target, level, xoffset, yoffset, zoffset, x, y, width, height) {
        this._glCheckError('copyTexSubImage3D');
        this.native.copyTexSubImage3D(target, level, xoffset, yoffset, zoffset, x, y, width, height);
    };
    TNSWebGL2RenderingContext.prototype.createQuery = function () {
        this._glCheckError('createQuery');
        return new canvas_plugin_common_1.WebGLQuery(this.native.createQuery());
    };
    TNSWebGL2RenderingContext.prototype.createSampler = function () {
        this._glCheckError('createSampler');
        return new canvas_plugin_common_1.WebGLSampler(this.native.createSampler());
    };
    TNSWebGL2RenderingContext.prototype.createTransformFeedback = function () {
        this._glCheckError('createTransformFeedback');
        return new canvas_plugin_common_1.WebGLTransformFeedback(this.native.createTransformFeedback());
    };
    TNSWebGL2RenderingContext.prototype.createVertexArray = function () {
        this._glCheckError('createVertexArray');
        return new canvas_plugin_common_1.WebGLVertexArrayObject(this.native.createVertexArray());
    };
    TNSWebGL2RenderingContext.prototype.deleteQueryWithQuery = function (query) {
        this._glCheckError('deleteQueryWithQuery');
        var value = query ? query.native : 0;
        this.native.deleteQuery(value);
    };
    TNSWebGL2RenderingContext.prototype.deleteSamplerWithSampler = function (sampler) {
        this._glCheckError('deleteSamplerWithSampler');
        var value = sampler ? sampler.native : 0;
        this.native.deleteSampler(value);
    };
    TNSWebGL2RenderingContext.prototype.deleteSyncWithSync = function (sync) {
        this._glCheckError('deleteSyncWithSync');
        var value = sync ? sync.native : 0;
        this.native.deleteSync(value);
    };
    TNSWebGL2RenderingContext.prototype.deleteTransformFeedback = function (transformFeedback) {
        this._glCheckError('deleteTransformFeedback');
        var value = transformFeedback ? transformFeedback.native : 0;
        this.native.deleteTransformFeedback(value);
    };
    TNSWebGL2RenderingContext.prototype.deleteVertexArray = function (vertexArray) {
        this._glCheckError('deleteVertexArray');
        var value = vertexArray ? vertexArray.native : 0;
        this.native.deleteVertexArray(value);
    };
    TNSWebGL2RenderingContext.prototype.drawArraysInstanced = function (mode, first, count, instanceCount) {
        this._glCheckError('drawArraysInstanced');
        this.native.drawArraysInstanced(mode, first, count, instanceCount);
    };
    TNSWebGL2RenderingContext.prototype.drawBuffers = function (buffers) {
        this._glCheckError('drawBuffers');
        this.native.drawBuffers(buffers);
    };
    TNSWebGL2RenderingContext.prototype.drawElementsInstanced = function (mode, count, type, offset, instanceCount) {
        this._glCheckError('drawElementsInstanced');
        this.native.drawElementsInstanced(mode, count, type, offset, instanceCount);
    };
    TNSWebGL2RenderingContext.prototype.drawRangeElements = function (mode, start, end, count, type, offset) {
        this._glCheckError('drawRangeElements');
        this.native.drawRangeElements(mode, start, end, count, type, offset);
    };
    TNSWebGL2RenderingContext.prototype.endQuery = function (target) {
        this._glCheckError('endQuery');
        this.native.endQuery(target);
    };
    TNSWebGL2RenderingContext.prototype.endTransformFeedback = function () {
        this._glCheckError('endTransformFeedback');
        this.native.endTransformFeedback();
    };
    TNSWebGL2RenderingContext.prototype.fenceSync = function (condition, flags) {
        this._glCheckError('fenceSync');
        this.native.fenceSync(condition, flags);
    };
    TNSWebGL2RenderingContext.prototype.framebufferTextureLayer = function (target, attachment, texture, level, layer) {
        this._glCheckError('framebufferTextureLayer');
        var value = texture ? texture.native : 0;
        this.native.framebufferTextureLayer(target, attachment, value, level, layer);
    };
    TNSWebGL2RenderingContext.prototype.getActiveUniformBlockName = function (program, uniformBlockIndex) {
        this._glCheckError('getActiveUniformBlockName');
        var value = program ? program.native : 0;
        return this.native.getActiveUniformBlockName(value, uniformBlockIndex);
    };
    TNSWebGL2RenderingContext.prototype.getActiveUniformBlockParameter = function (program, uniformBlockIndex, pname) {
        this._glCheckError('getActiveUniformBlockParameter');
        var value = program ? program.native : 0;
        var param = this.native.getActiveUniformBlockParameter(value, uniformBlockIndex, pname);
        if (pname === this.UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES) {
            return new Uint32Array(this.getJSArray(param));
        }
        return TNSWebGL2RenderingContext.toPrimitive(param);
    };
    TNSWebGL2RenderingContext.toPrimitive = function (value) {
        if (value instanceof java.lang.Integer) {
            return value.intValue();
        }
        else if (value instanceof java.lang.Long) {
            return value.longValue();
        }
        else if (value instanceof java.lang.Short) {
            return value.shortValue();
        }
        else if (value instanceof java.lang.Byte) {
            return value.byteValue();
        }
        else if (value instanceof java.lang.Boolean) {
            return value.booleanValue();
        }
        else if (value instanceof java.lang.String) {
            return value.toString();
        }
        else if (value instanceof java.lang.Float) {
            return value.floatValue();
        }
        else if (value instanceof java.lang.Double) {
            return value.doubleValue();
        }
        return value;
    };
    TNSWebGL2RenderingContext.prototype.getActiveUniforms = function (program, uniformIndices, pname) {
        this._glCheckError('getActiveUniforms');
        var value = program ? program.native : 0;
        return this.getJSArray(this.native.getActiveUniforms(value, uniformIndices, pname));
    };
    TNSWebGL2RenderingContext.prototype.getBufferSubData = function (target, srcByteOffset, dstData, dstOffset, length) {
        if (dstOffset === void 0) { dstOffset = 0; }
        if (length === void 0) { length = 0; }
        this._glCheckError('getBufferSubData');
        this.native.getBufferSubData(target, srcByteOffset, new Uint8Array(dstData.slice(0)), dstOffset, length);
    };
    TNSWebGL2RenderingContext.prototype.getFragDataLocation = function (program, name) {
        this._glCheckError('getFragDataLocation');
        var value = program ? program.native : 0;
        var result = this.native.getFragDataLocation(value, name);
        return result !== -1 ? result : null;
    };
    TNSWebGL2RenderingContext.prototype.getIndexedParameter = function (target, index) {
        this._glCheckError('getIndexedParameter');
        var param = this.native.getIndexedParameter(target, index);
        if (target === this.TRANSFORM_FEEDBACK_BUFFER_BINDING ||
            target === this.UNIFORM_BUFFER_BINDING) {
            return new canvas_plugin_common_1.WebGLBuffer(param);
        }
        return TNSWebGL2RenderingContext.toPrimitive(param);
    };
    TNSWebGL2RenderingContext.prototype.getInternalformatParameter = function (target, internalformat, pname) {
        this._glCheckError('getInternalformatParameter');
        var param = this.native.getInternalformatParameter(target, internalformat, pname);
        if (pname === this.SAMPLES) {
            return new Int32Array(this.getJSArray(param));
        }
        return TNSWebGL2RenderingContext.toPrimitive(param);
        ;
    };
    TNSWebGL2RenderingContext.prototype.getQueryParameter = function (query, pname) {
        this._glCheckError('getQueryParameter');
        var value = query ? query.native : 0;
        var result = this.native.getQueryParameter(value, pname);
        if (result === 0) {
            return null;
        }
        return TNSWebGL2RenderingContext.toPrimitive(result);
    };
    TNSWebGL2RenderingContext.prototype.getQuery = function (target, pname) {
        this._glCheckError('getQuery');
        var query = this.native.getQuery(target, pname);
        if (query) {
            return new canvas_plugin_common_1.WebGLQuery(query);
        }
        return null;
    };
    TNSWebGL2RenderingContext.prototype.getSamplerParameter = function (sampler, pname) {
        this._glCheckError('getSamplerParameter');
        var value = sampler ? sampler.native : 0;
        return TNSWebGL2RenderingContext.toPrimitive(this.native.getSamplerParameter(value, pname));
    };
    TNSWebGL2RenderingContext.prototype.getSyncParameter = function (sync, pname) {
        this._glCheckError('getSyncParameter');
        var value = sync ? sync.native : 0;
        return TNSWebGL2RenderingContext.toPrimitive(this.native.getSyncParameter(value, pname));
    };
    TNSWebGL2RenderingContext.prototype.getTransformFeedbackVarying = function (program, index) {
        this._glCheckError('getTransformFeedbackVarying');
        var value = program ? program.native : 0;
        var info = this.native.getTransformFeedbackVarying(value, index);
        if (info) {
            return new canvas_plugin_common_1.WebGLActiveInfo(info.name, info.size, info.size);
        }
        return null;
    };
    TNSWebGL2RenderingContext.prototype.getUniformBlockIndex = function (program, uniformBlockName) {
        this._glCheckError('getUniformBlockIndex');
        var value = program ? program.native : 0;
        return this.native.getUniformBlockIndex(value, uniformBlockName);
    };
    TNSWebGL2RenderingContext.prototype.getUniformIndices = function (program, uniformNames) {
        this._glCheckError('getUniformIndices');
        var value = program ? program.native : 0;
        return this.getJSArray(this.native.getUniformIndices(value, uniformNames));
    };
    TNSWebGL2RenderingContext.prototype.invalidateFramebuffer = function (target, attachments) {
        this._glCheckError('invalidateFramebuffer');
        this.native.invalidateFramebuffer(target, attachments);
    };
    TNSWebGL2RenderingContext.prototype.invalidateSubFramebuffer = function (target, attachments, x, y, width, height) {
        this._glCheckError('invalidateSubFramebuffer');
        this.native.invalidateSubFramebuffer(target, attachments, x, y, width, height);
    };
    TNSWebGL2RenderingContext.prototype.isQuery = function (query) {
        this._glCheckError('isQuery');
        var value = query ? query.native : 0;
        return this.native.isQuery(value);
    };
    TNSWebGL2RenderingContext.prototype.isSampler = function (sampler) {
        this._glCheckError('isSampler');
        var value = sampler ? sampler.native : 0;
        return this.native.isSampler(value);
    };
    TNSWebGL2RenderingContext.prototype.isSync = function (sync) {
        this._glCheckError('isSync');
        var value = sync ? sync.native : 0;
        return this.native.isSync(value);
    };
    TNSWebGL2RenderingContext.prototype.isTransformFeedback = function (transformFeedback) {
        this._glCheckError('isTransformFeedback');
        var value = transformFeedback ? transformFeedback.native : 0;
        return this.native.isTransformFeedback(value);
    };
    TNSWebGL2RenderingContext.prototype.isVertexArray = function (vertexArray) {
        this._glCheckError('isVertexArray');
        var value = vertexArray ? vertexArray.native : 0;
        return this.native.isVertexArray(value);
    };
    TNSWebGL2RenderingContext.prototype.pauseTransformFeedback = function () {
        this._glCheckError('pauseTransformFeedback');
        this.native.pauseTransformFeedback();
    };
    TNSWebGL2RenderingContext.prototype.readBuffer = function (src) {
        this._glCheckError('readBuffer');
        this.native.readBuffer(src);
    };
    TNSWebGL2RenderingContext.prototype.renderbufferStorageMultisample = function (target, samples, internalFormat, width, height) {
        this._glCheckError('renderbufferStorageMultisample');
        this.native.renderbufferStorageMultisample(target, samples, internalFormat, width, height);
    };
    TNSWebGL2RenderingContext.prototype.resumeTransformFeedback = function () {
        this._glCheckError('resumeTransformFeedback');
        this.native.resumeTransformFeedback();
    };
    TNSWebGL2RenderingContext.prototype.samplerParameterf = function (sampler, pname, param) {
        this._glCheckError('samplerParameterf');
        var value = sampler ? sampler.native : 0;
        this.native.samplerParameterf(value, pname, param);
    };
    TNSWebGL2RenderingContext.prototype.samplerParameteri = function (sampler, pname, param) {
        this._glCheckError('samplerParameteri');
        var value = sampler ? sampler.native : 0;
        this.native.samplerParameteri(value, pname, param);
    };
    TNSWebGL2RenderingContext.prototype.texImage3D = function (target, level, internalformat, width, height, depth, border, format, type, source) {
        this._glCheckError('texImage3D');
        if (typeof source === 'number') {
            this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, source);
        }
        else if (source && source.buffer) {
            if (source instanceof Uint8Array) {
                this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, this.toNativeArray(source, 'byte'));
            }
        }
        else if (source instanceof android.graphics.Bitmap) {
            this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, source);
        }
        else if (source instanceof image_source_1.ImageSource) {
            this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, source.android);
        }
        else if (source instanceof TNSImageAsset_1.TNSImageAsset) {
            this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, source.native);
        }
        else if (source &&
            typeof source.tagName === 'string' &&
            source.tagName === 'IMG') {
            if (source._imageSource instanceof image_source_1.ImageSource) {
                this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, source._imageSource.android);
            }
            else if (source._image instanceof android.graphics.Bitmap) {
                this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, source._image);
            }
            else if (source._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, source._asset.native);
            }
            else if (typeof source.src === 'string') {
                var result = image_source_1.fromFile(source.src);
                this.native.texImage3D(target, level, internalformat, width, height, depth, border, format, type, result ? result.android : null);
            }
        }
    };
    TNSWebGL2RenderingContext.prototype.texStorage2D = function (target, levels, internalformat, width, height) {
        this._glCheckError('texStorage2D');
        this.native.texStorage2D(target, levels, internalformat, width, height);
    };
    TNSWebGL2RenderingContext.prototype.texStorage3D = function (target, levels, internalformat, width, height, depth) {
        this._glCheckError('texStorage3D');
        this.native.texStorage3D(target, levels, internalformat, width, height, depth);
    };
    TNSWebGL2RenderingContext.prototype.texSubImage3D = function (target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData, srcOffset) {
        if (srcOffset === void 0) { srcOffset = 0; }
        this._glCheckError('texSubImage3D');
        if (typeof srcData === 'number') {
            this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData);
        }
        else if (srcData && srcData.buffer) {
            if (srcData instanceof Uint8Array) {
                if (srcOffset) {
                    this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, this.toNativeArray(srcData, 'byte'), srcOffset);
                }
                else {
                    this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, this.toNativeArray(srcData, 'byte'));
                }
            }
        }
        else if (srcData instanceof android.graphics.Bitmap) {
            this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData);
        }
        else if (srcData instanceof image_source_1.ImageSource) {
            this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData.android);
        }
        else if (srcData instanceof TNSImageAsset_1.TNSImageAsset) {
            this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData.native);
        }
        else if (srcData &&
            typeof srcData.tagName === 'string' &&
            srcData.tagName === 'IMG') {
            if (srcData._imageSource instanceof image_source_1.ImageSource) {
                this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData._imageSource.android);
            }
            else if (srcData._image instanceof android.graphics.Bitmap) {
                this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData._image);
            }
            else if (srcData._asset instanceof TNSImageAsset_1.TNSImageAsset) {
                this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, srcData._asset.native);
            }
            else if (typeof srcData.src === 'string') {
                var result = image_source_1.fromFile(srcData.src);
                this.native.texSubImage3D(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, result ? result.android : null);
            }
        }
    };
    TNSWebGL2RenderingContext.prototype.transformFeedbackVaryings = function (program, varyings, bufferMode) {
        this._glCheckError('transformFeedbackVaryings');
        var value = program ? program.native : 0;
        this.native.transformFeedbackVaryings(value, varyings, bufferMode);
    };
    TNSWebGL2RenderingContext.prototype.uniform1ui = function (location, v0) {
        this._glCheckError('uniform1ui');
        var value = location ? location.native : 0;
        this.native.uniform1ui(value, v0);
    };
    TNSWebGL2RenderingContext.prototype.uniform1uiv = function (location, data) {
        this._glCheckError('uniform1uiv');
        var value = location ? location.native : 0;
        this.native.uniform1uiv(value, data);
    };
    TNSWebGL2RenderingContext.prototype.uniform2ui = function (location, v0, v1) {
        this._glCheckError('uniform2ui');
        var value = location ? location.native : 0;
        this.native.uniform2ui(value, v0, v1);
    };
    TNSWebGL2RenderingContext.prototype.uniform2uiv = function (location, data) {
        this._glCheckError('uniform2uiv');
        var value = location ? location.native : 0;
        this.native.uniform2uiv(value, data);
    };
    TNSWebGL2RenderingContext.prototype.uniform3ui = function (location, v0, v1, v2) {
        this._glCheckError('uniform3ui');
        var value = location ? location.native : 0;
        this.native.uniform3ui(value, v0, v1, v2);
    };
    TNSWebGL2RenderingContext.prototype.uniform3uiv = function (location, data) {
        this._glCheckError('uniform3uiv');
        var value = location ? location.native : 0;
        this.native.uniform3uiv(value, data);
    };
    TNSWebGL2RenderingContext.prototype.uniform4ui = function (location, v0, v1, v2, v3) {
        this._glCheckError('uniform4ui');
        var value = location ? location.native : 0;
        this.native.uniform4ui(value, v0, v1, v2, v3);
    };
    TNSWebGL2RenderingContext.prototype.uniform4uiv = function (location, data) {
        this._glCheckError('uniform4uiv');
        var value = location ? location.native : 0;
        this.native.uniform4uiv(value, data);
    };
    TNSWebGL2RenderingContext.prototype.uniformBlockBinding = function (program, uniformBlockIndex, uniformBlockBinding) {
        this._glCheckError('uniformBlockBinding');
        var value = program ? program.native : 0;
        this.native.uniformBlockBinding(value, uniformBlockIndex, uniformBlockBinding);
    };
    TNSWebGL2RenderingContext.prototype.uniformMatrix2x3fv = function (location, transpose, data) {
        if (data instanceof Float32Array) {
            data = this.toNativeArray(data, 'float');
        }
        this._glCheckError('uniformMatrix2x3fv');
        var value = location ? location.native : 0;
        this.native.uniformMatrix2x3fv(value, transpose, data);
    };
    TNSWebGL2RenderingContext.prototype.uniformMatrix2x4fv = function (location, transpose, data) {
        if (data instanceof Float32Array) {
            data = this.toNativeArray(data, 'float');
        }
        this._glCheckError('uniformMatrix2x4fv');
        var value = location ? location.native : 0;
        this.native.uniformMatrix2x4fv(value, transpose, data);
    };
    TNSWebGL2RenderingContext.prototype.uniformMatrix3x2fv = function (location, transpose, data) {
        if (data instanceof Float32Array) {
            data = this.toNativeArray(data, 'float');
        }
        this._glCheckError('uniformMatrix3x2fv');
        var value = location ? location.native : 0;
        this.native.uniformMatrix3x2fv(value, transpose, data);
    };
    TNSWebGL2RenderingContext.prototype.uniformMatrix3x4fv = function (location, transpose, data) {
        if (data instanceof Float32Array) {
            data = this.toNativeArray(data, 'float');
        }
        this._glCheckError('uniformMatrix3x4fv');
        var value = location ? location.native : 0;
        this.native.uniformMatrix3x4fv(value, transpose, data);
    };
    TNSWebGL2RenderingContext.prototype.uniformMatrix4x2fv = function (location, transpose, data) {
        if (data instanceof Float32Array) {
            data = this.toNativeArray(data, 'float');
        }
        this._glCheckError('uniformMatrix4x2fv');
        var value = location ? location.native : 0;
        this.native.uniformMatrix4x2fv(value, transpose, data);
    };
    TNSWebGL2RenderingContext.prototype.uniformMatrix4x3fv = function (location, transpose, data) {
        if (data instanceof Float32Array) {
            data = this.toNativeArray(data, 'float');
        }
        this._glCheckError('uniformMatrix4x3fv');
        var value = location ? location.native : 0;
        this.native.uniformMatrix4x3fv(value, transpose, data);
    };
    TNSWebGL2RenderingContext.prototype.vertexAttribDivisor = function (index, divisor) {
        this._glCheckError('vertexAttribDivisor');
        this.native.vertexAttribDivisor(index, divisor);
    };
    TNSWebGL2RenderingContext.prototype.vertexAttribI4i = function (index, v0, v1, v2, v3) {
        this._glCheckError('vertexAttribI4i');
        this.native.vertexAttribI4i(index, v0, v1, v2, v3);
    };
    TNSWebGL2RenderingContext.prototype.vertexAttribI4iv = function (index, value) {
        if (value instanceof Int32Array) {
            value = this.toNativeArray(value, 'int');
        }
        this._glCheckError('vertexAttribI4iv');
        this.native.vertexAttribI4uiv(index, value);
    };
    TNSWebGL2RenderingContext.prototype.vertexAttribI4ui = function (index, v0, v1, v2, v3) {
        this._glCheckError('vertexAttribI4ui');
        this.native.vertexAttribI4ui(index, v0, v1, v2, v3);
    };
    TNSWebGL2RenderingContext.prototype.vertexAttribI4uiv = function (index, value) {
        if (value instanceof Uint32Array) {
            value = this.toNativeArray(value, 'int');
        }
        this._glCheckError('vertexAttribI4uiv');
        this.native.vertexAttribI4uiv(index, value);
    };
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "READ_BUFFER", {
        get: function () { return this.native.READ_BUFFER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNPACK_ROW_LENGTH", {
        get: function () { return this.native.UNPACK_ROW_LENGTH; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNPACK_SKIP_ROWS", {
        get: function () { return this.native.UNPACK_SKIP_ROWS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNPACK_SKIP_PIXELS", {
        get: function () { return this.native.UNPACK_SKIP_PIXELS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "PACK_ROW_LENGTH", {
        get: function () { return this.native.PACK_ROW_LENGTH; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "PACK_SKIP_ROWS", {
        get: function () { return this.native.PACK_SKIP_ROWS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "PACK_SKIP_PIXELS", {
        get: function () { return this.native.PACK_SKIP_PIXELS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TEXTURE_BINDING_3D", {
        get: function () { return this.native.TEXTURE_BINDING_3D; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNPACK_SKIP_IMAGES", {
        get: function () { return this.native.UNPACK_SKIP_IMAGES; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNPACK_IMAGE_HEIGHT", {
        get: function () { return this.native.UNPACK_IMAGE_HEIGHT; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_3D_TEXTURE_SIZE", {
        get: function () { return this.native.MAX_3D_TEXTURE_SIZE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_ELEMENTS_VERTICES", {
        get: function () { return this.native.MAX_ELEMENTS_VERTICES; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_ELEMENTS_INDICES", {
        get: function () { return this.native.MAX_ELEMENTS_INDICES; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_TEXTURE_LOD_BIAS", {
        get: function () { return this.native.MAX_TEXTURE_LOD_BIAS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_FRAGMENT_UNIFORM_COMPONENTS", {
        get: function () { return this.native.MAX_FRAGMENT_UNIFORM_COMPONENTS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_VERTEX_UNIFORM_COMPONENTS", {
        get: function () { return this.native.MAX_VERTEX_UNIFORM_COMPONENTS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_ARRAY_TEXTURE_LAYERS", {
        get: function () { return this.native.MAX_ARRAY_TEXTURE_LAYERS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MIN_PROGRAM_TEXEL_OFFSET", {
        get: function () { return this.native.MIN_PROGRAM_TEXEL_OFFSET; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_PROGRAM_TEXEL_OFFSET", {
        get: function () { return this.native.MAX_PROGRAM_TEXEL_OFFSET; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_VARYING_COMPONENTS", {
        get: function () { return this.native.MAX_VARYING_COMPONENTS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FRAGMENT_SHADER_DERIVATIVE_HINT", {
        get: function () { return this.native.FRAGMENT_SHADER_DERIVATIVE_HINT; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RASTERIZER_DISCARD", {
        get: function () { return this.native.RASTERIZER_DISCARD; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "VERTEX_ARRAY_BINDING", {
        get: function () { return this.native.VERTEX_ARRAY_BINDING; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_VERTEX_OUTPUT_COMPONENTS", {
        get: function () { return this.native.MAX_VERTEX_OUTPUT_COMPONENTS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_FRAGMENT_INPUT_COMPONENTS", {
        get: function () { return this.native.MAX_FRAGMENT_INPUT_COMPONENTS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_SERVER_WAIT_TIMEOUT", {
        get: function () { return this.native.MAX_SERVER_WAIT_TIMEOUT; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_ELEMENT_INDEX", {
        get: function () { return this.native.MAX_ELEMENT_INDEX; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RED", {
        get: function () { return this.native.RED; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGB8", {
        get: function () { return this.native.RGB8; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGBA8", {
        get: function () { return this.native.RGBA8; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGB10_A2", {
        get: function () { return this.native.RGB10_A2; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TEXTURE_3D", {
        get: function () { return this.native.TEXTURE_3D; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TEXTURE_WRAP_R", {
        get: function () { return this.native.TEXTURE_WRAP_R; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TEXTURE_MIN_LOD", {
        get: function () { return this.native.TEXTURE_MIN_LOD; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TEXTURE_MAX_LOD", {
        get: function () { return this.native.TEXTURE_MAX_LOD; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TEXTURE_BASE_LEVEL", {
        get: function () { return this.native.TEXTURE_BASE_LEVEL; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TEXTURE_MAX_LEVEL", {
        get: function () { return this.native.TEXTURE_MAX_LEVEL; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TEXTURE_COMPARE_MODE", {
        get: function () { return this.native.TEXTURE_COMPARE_MODE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TEXTURE_COMPARE_FUNC", {
        get: function () { return this.native.TEXTURE_COMPARE_FUNC; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SRGB", {
        get: function () { return this.native.SRGB; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SRGB8", {
        get: function () { return this.native.SRGB8; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SRGB8_ALPHA8", {
        get: function () { return this.native.SRGB8_ALPHA8; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COMPARE_REF_TO_TEXTURE", {
        get: function () { return this.native.COMPARE_REF_TO_TEXTURE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGBA32F", {
        get: function () { return this.native.RGBA32F; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGB32F", {
        get: function () { return this.native.RGB32F; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGBA16F", {
        get: function () { return this.native.RGBA16F; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGB16F", {
        get: function () { return this.native.RGB16F; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TEXTURE_2D_ARRAY", {
        get: function () { return this.native.TEXTURE_2D_ARRAY; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TEXTURE_BINDING_2D_ARRAY", {
        get: function () { return this.native.TEXTURE_BINDING_2D_ARRAY; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "R11F_G11F_B10F", {
        get: function () { return this.native.R11F_G11F_B10F; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGB9_E5", {
        get: function () { return this.native.RGB9_E5; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGBA32UI", {
        get: function () { return this.native.RGBA32UI; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGB32UI", {
        get: function () { return this.native.RGB32UI; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGBA16UI", {
        get: function () { return this.native.RGBA16UI; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGB16UI", {
        get: function () { return this.native.RGB16UI; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGBA8UI", {
        get: function () { return this.native.RGBA8UI; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGB8UI", {
        get: function () { return this.native.RGB8UI; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGBA32I", {
        get: function () { return this.native.RGBA32I; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGB32I", {
        get: function () { return this.native.RGB32I; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGBA16I", {
        get: function () { return this.native.RGBA16I; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGB16I", {
        get: function () { return this.native.RGB16I; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGBA8I", {
        get: function () { return this.native.RGBA8I; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGB8I", {
        get: function () { return this.native.RGB8I; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RED_INTEGER", {
        get: function () { return this.native.RED_INTEGER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGB_INTEGER", {
        get: function () { return this.native.RGB_INTEGER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGBA_INTEGER", {
        get: function () { return this.native.RGBA_INTEGER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "R8", {
        get: function () { return this.native.R8; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RG8", {
        get: function () { return this.native.RG8; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "R16F", {
        get: function () { return this.native.R16F; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "R32F", {
        get: function () { return this.native.R32F; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RG16F", {
        get: function () { return this.native.RG16F; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RG32F", {
        get: function () { return this.native.RG32F; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "R8I", {
        get: function () { return this.native.R8I; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "R8UI", {
        get: function () { return this.native.R8UI; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "R16I", {
        get: function () { return this.native.R16I; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "R16UI", {
        get: function () { return this.native.R16UI; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "R32I", {
        get: function () { return this.native.R32I; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "R32UI", {
        get: function () { return this.native.R32UI; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RG8I", {
        get: function () { return this.native.RG8I; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RG8UI", {
        get: function () { return this.native.RG8UI; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RG16I", {
        get: function () { return this.native.RG16I; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RG16UI", {
        get: function () { return this.native.RG16UI; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RG32I", {
        get: function () { return this.native.RG32I; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RG32UI", {
        get: function () { return this.native.RG32UI; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "R8_SNORM", {
        get: function () { return this.native.R8_SNORM; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RG8_SNORM", {
        get: function () { return this.native.RG8_SNORM; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGB8_SNORM", {
        get: function () { return this.native.RGB8_SNORM; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGBA8_SNORM", {
        get: function () { return this.native.RGBA8_SNORM; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RGB10_A2UI", {
        get: function () { return this.native.RGB10_A2UI; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TEXTURE_IMMUTABLE_FORMAT", {
        get: function () { return this.native.TEXTURE_IMMUTABLE_FORMAT; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TEXTURE_IMMUTABLE_LEVELS", {
        get: function () { return this.native.TEXTURE_IMMUTABLE_LEVELS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNSIGNED_INT_2_10_10_10_REV", {
        get: function () { return this.native.UNSIGNED_INT_2_10_10_10_REV; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNSIGNED_INT_10F_11F_11F_REV", {
        get: function () { return this.native.UNSIGNED_INT_10F_11F_11F_REV; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNSIGNED_INT_5_9_9_9_REV", {
        get: function () { return this.native.UNSIGNED_INT_5_9_9_9_REV; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FLOAT_32_UNSIGNED_INT_24_8_REV", {
        get: function () { return this.native.FLOAT_32_UNSIGNED_INT_24_8_REV; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNSIGNED_INT_24_8", {
        get: function () { return this.native.UNSIGNED_INT_24_8; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "HALF_FLOAT", {
        get: function () { return this.native.HALF_FLOAT; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RG", {
        get: function () { return this.native.RG; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RG_INTEGER", {
        get: function () { return this.native.RG_INTEGER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "INT_2_10_10_10_REV", {
        get: function () { return this.native.INT_2_10_10_10_REV; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "QUERY_RESULT_AVAILABLE", {
        get: function () { return this.native.QUERY_RESULT_AVAILABLE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "QUERY_RESULT", {
        get: function () { return this.native.QUERY_RESULT; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "CURRENT_QUERY", {
        get: function () { return this.native.CURRENT_QUERY; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "ANY_SAMPLES_PASSED", {
        get: function () { return this.native.ANY_SAMPLES_PASSED; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "ANY_SAMPLES_PASSED_CONSERVATIVE", {
        get: function () { return this.native.ANY_SAMPLES_PASSED_CONSERVATIVE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_DRAW_BUFFERS", {
        get: function () { return this.native.MAX_DRAW_BUFFERS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER0", {
        get: function () { return this.native.DRAW_BUFFER0; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER1", {
        get: function () { return this.native.DRAW_BUFFER1; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER2", {
        get: function () { return this.native.DRAW_BUFFER2; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER3", {
        get: function () { return this.native.DRAW_BUFFER3; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER4", {
        get: function () { return this.native.DRAW_BUFFER4; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER5", {
        get: function () { return this.native.DRAW_BUFFER5; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER6", {
        get: function () { return this.native.DRAW_BUFFER6; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER7", {
        get: function () { return this.native.DRAW_BUFFER7; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER8", {
        get: function () { return this.native.DRAW_BUFFER8; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER9", {
        get: function () { return this.native.DRAW_BUFFER9; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER10", {
        get: function () { return this.native.DRAW_BUFFER10; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER11", {
        get: function () { return this.native.DRAW_BUFFER11; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER12", {
        get: function () { return this.native.DRAW_BUFFER12; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER13", {
        get: function () { return this.native.DRAW_BUFFER13; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER14", {
        get: function () { return this.native.DRAW_BUFFER14; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_BUFFER15", {
        get: function () { return this.native.DRAW_BUFFER15; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_COLOR_ATTACHMENTS", {
        get: function () { return this.native.MAX_COLOR_ATTACHMENTS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR_ATTACHMENT1", {
        get: function () { return this.native.COLOR_ATTACHMENT1; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR_ATTACHMENT2", {
        get: function () { return this.native.COLOR_ATTACHMENT2; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR_ATTACHMENT3", {
        get: function () { return this.native.COLOR_ATTACHMENT3; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR_ATTACHMENT4", {
        get: function () { return this.native.COLOR_ATTACHMENT4; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR_ATTACHMENT5", {
        get: function () { return this.native.COLOR_ATTACHMENT5; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR_ATTACHMENT6", {
        get: function () { return this.native.COLOR_ATTACHMENT6; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR_ATTACHMENT7", {
        get: function () { return this.native.COLOR_ATTACHMENT7; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR_ATTACHMENT8", {
        get: function () { return this.native.COLOR_ATTACHMENT8; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR_ATTACHMENT9", {
        get: function () { return this.native.COLOR_ATTACHMENT9; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR_ATTACHMENT10", {
        get: function () { return this.native.COLOR_ATTACHMENT10; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR_ATTACHMENT11", {
        get: function () { return this.native.COLOR_ATTACHMENT11; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR_ATTACHMENT12", {
        get: function () { return this.native.COLOR_ATTACHMENT12; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR_ATTACHMENT13", {
        get: function () { return this.native.COLOR_ATTACHMENT13; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR_ATTACHMENT14", {
        get: function () { return this.native.COLOR_ATTACHMENT14; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR_ATTACHMENT15", {
        get: function () { return this.native.COLOR_ATTACHMENT15; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SAMPLER_3D", {
        get: function () { return this.native.SAMPLER_3D; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SAMPLER_2D_SHADOW", {
        get: function () { return this.native.SAMPLER_2D_SHADOW; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SAMPLER_2D_ARRAY", {
        get: function () { return this.native.SAMPLER_2D_ARRAY; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SAMPLER_2D_ARRAY_SHADOW", {
        get: function () { return this.native.SAMPLER_2D_ARRAY_SHADOW; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SAMPLER_CUBE_SHADOW", {
        get: function () { return this.native.SAMPLER_CUBE_SHADOW; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "INT_SAMPLER_2D", {
        get: function () { return this.native.INT_SAMPLER_2D; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "INT_SAMPLER_3D", {
        get: function () { return this.native.INT_SAMPLER_3D; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "INT_SAMPLER_CUBE", {
        get: function () { return this.native.INT_SAMPLER_CUBE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "INT_SAMPLER_2D_ARRAY", {
        get: function () { return this.native.INT_SAMPLER_2D_ARRAY; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNSIGNED_INT_SAMPLER_2D", {
        get: function () { return this.native.UNSIGNED_INT_SAMPLER_2D; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNSIGNED_INT_SAMPLER_3D", {
        get: function () { return this.native.UNSIGNED_INT_SAMPLER_3D; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNSIGNED_INT_SAMPLER_CUBE", {
        get: function () { return this.native.UNSIGNED_INT_SAMPLER_CUBE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNSIGNED_INT_SAMPLER_2D_ARRAY", {
        get: function () { return this.native.UNSIGNED_INT_SAMPLER_2D_ARRAY; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_SAMPLES", {
        get: function () { return this.native.MAX_SAMPLES; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SAMPLER_BINDING", {
        get: function () { return this.native.SAMPLER_BINDING; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "PIXEL_PACK_BUFFER", {
        get: function () { return this.native.PIXEL_PACK_BUFFER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "PIXEL_UNPACK_BUFFER", {
        get: function () { return this.native.PIXEL_UNPACK_BUFFER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "PIXEL_PACK_BUFFER_BINDING", {
        get: function () { return this.native.PIXEL_PACK_BUFFER_BINDING; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "PIXEL_UNPACK_BUFFER_BINDING", {
        get: function () { return this.native.PIXEL_UNPACK_BUFFER_BINDING; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COPY_READ_BUFFER", {
        get: function () { return this.native.COPY_READ_BUFFER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COPY_WRITE_BUFFER", {
        get: function () { return this.native.COPY_WRITE_BUFFER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COPY_READ_BUFFER_BINDING", {
        get: function () { return this.native.COPY_READ_BUFFER_BINDING; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COPY_WRITE_BUFFER_BINDING", {
        get: function () { return this.native.COPY_WRITE_BUFFER_BINDING; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FLOAT_MAT2x3", {
        get: function () { return this.native.FLOAT_MAT2x3; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FLOAT_MAT2x4", {
        get: function () { return this.native.FLOAT_MAT2x4; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FLOAT_MAT3x2", {
        get: function () { return this.native.FLOAT_MAT3x2; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FLOAT_MAT3x4", {
        get: function () { return this.native.FLOAT_MAT3x4; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FLOAT_MAT4x2", {
        get: function () { return this.native.FLOAT_MAT4x2; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FLOAT_MAT4x3", {
        get: function () { return this.native.FLOAT_MAT4x3; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNSIGNED_INT_VEC2", {
        get: function () { return this.native.UNSIGNED_INT_VEC2; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNSIGNED_INT_VEC3", {
        get: function () { return this.native.UNSIGNED_INT_VEC3; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNSIGNED_INT_VEC4", {
        get: function () { return this.native.UNSIGNED_INT_VEC4; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNSIGNED_NORMALIZED", {
        get: function () { return this.native.UNSIGNED_NORMALIZED; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SIGNED_NORMALIZED", {
        get: function () { return this.native.SIGNED_NORMALIZED; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_INTEGER", {
        get: function () { return this.native.VERTEX_ATTRIB_ARRAY_INTEGER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "VERTEX_ATTRIB_ARRAY_DIVISOR", {
        get: function () { return this.native.VERTEX_ATTRIB_ARRAY_DIVISOR; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TRANSFORM_FEEDBACK_BUFFER_MODE", {
        get: function () { return this.native.TRANSFORM_FEEDBACK_BUFFER_MODE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS", {
        get: function () { return this.native.MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TRANSFORM_FEEDBACK_VARYINGS", {
        get: function () { return this.native.TRANSFORM_FEEDBACK_VARYINGS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TRANSFORM_FEEDBACK_BUFFER_START", {
        get: function () { return this.native.TRANSFORM_FEEDBACK_BUFFER_START; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TRANSFORM_FEEDBACK_BUFFER_SIZE", {
        get: function () { return this.native.TRANSFORM_FEEDBACK_BUFFER_SIZE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN", {
        get: function () { return this.native.TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS", {
        get: function () { return this.native.MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS", {
        get: function () { return this.native.MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "INTERLEAVED_ATTRIBS", {
        get: function () { return this.native.INTERLEAVED_ATTRIBS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SEPARATE_ATTRIBS", {
        get: function () { return this.native.SEPARATE_ATTRIBS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TRANSFORM_FEEDBACK_BUFFER", {
        get: function () { return this.native.TRANSFORM_FEEDBACK_BUFFER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TRANSFORM_FEEDBACK_BUFFER_BINDING", {
        get: function () { return this.native.TRANSFORM_FEEDBACK_BUFFER_BINDING; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TRANSFORM_FEEDBACK", {
        get: function () { return this.native.TRANSFORM_FEEDBACK; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TRANSFORM_FEEDBACK_PAUSED", {
        get: function () { return this.native.TRANSFORM_FEEDBACK_PAUSED; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TRANSFORM_FEEDBACK_ACTIVE", {
        get: function () { return this.native.TRANSFORM_FEEDBACK_ACTIVE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TRANSFORM_FEEDBACK_BINDING", {
        get: function () { return this.native.TRANSFORM_FEEDBACK_BINDING; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING", {
        get: function () { return this.native.FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE", {
        get: function () { return this.native.FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_RED_SIZE", {
        get: function () { return this.native.FRAMEBUFFER_ATTACHMENT_RED_SIZE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_GREEN_SIZE", {
        get: function () { return this.native.FRAMEBUFFER_ATTACHMENT_GREEN_SIZE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_BLUE_SIZE", {
        get: function () { return this.native.FRAMEBUFFER_ATTACHMENT_BLUE_SIZE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE", {
        get: function () { return this.native.FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE", {
        get: function () { return this.native.FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE", {
        get: function () { return this.native.FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FRAMEBUFFER_DEFAULT", {
        get: function () { return this.native.FRAMEBUFFER_DEFAULT; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DEPTH_STENCIL_ATTACHMENT", {
        get: function () { return this.native.DEPTH_STENCIL_ATTACHMENT; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DEPTH_STENCIL", {
        get: function () { return this.native.DEPTH_STENCIL; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DEPTH24_STENCIL8", {
        get: function () { return this.native.DEPTH24_STENCIL8; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_FRAMEBUFFER_BINDING", {
        get: function () { return this.native.DRAW_FRAMEBUFFER_BINDING; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "READ_FRAMEBUFFER", {
        get: function () { return this.native.READ_FRAMEBUFFER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DRAW_FRAMEBUFFER", {
        get: function () { return this.native.DRAW_FRAMEBUFFER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "READ_FRAMEBUFFER_BINDING", {
        get: function () { return this.native.READ_FRAMEBUFFER_BINDING; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "RENDERBUFFER_SAMPLES", {
        get: function () { return this.native.RENDERBUFFER_SAMPLES; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER", {
        get: function () { return this.native.FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "FRAMEBUFFER_INCOMPLETE_MULTISAMPLE", {
        get: function () { return this.native.FRAMEBUFFER_INCOMPLETE_MULTISAMPLE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_BUFFER", {
        get: function () { return this.native.UNIFORM_BUFFER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_BUFFER_BINDING", {
        get: function () { return this.native.UNIFORM_BUFFER_BINDING; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_BUFFER_START", {
        get: function () { return this.native.UNIFORM_BUFFER_START; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_BUFFER_SIZE", {
        get: function () { return this.native.UNIFORM_BUFFER_SIZE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_VERTEX_UNIFORM_BLOCKS", {
        get: function () { return this.native.MAX_VERTEX_UNIFORM_BLOCKS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_FRAGMENT_UNIFORM_BLOCKS", {
        get: function () { return this.native.MAX_FRAGMENT_UNIFORM_BLOCKS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_COMBINED_UNIFORM_BLOCKS", {
        get: function () { return this.native.MAX_COMBINED_UNIFORM_BLOCKS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_UNIFORM_BUFFER_BINDINGS", {
        get: function () { return this.native.MAX_UNIFORM_BUFFER_BINDINGS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_UNIFORM_BLOCK_SIZE", {
        get: function () { return this.native.MAX_UNIFORM_BLOCK_SIZE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS", {
        get: function () { return this.native.MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS", {
        get: function () { return this.native.MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_BUFFER_OFFSET_ALIGNMENT", {
        get: function () { return this.native.UNIFORM_BUFFER_OFFSET_ALIGNMENT; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "ACTIVE_UNIFORM_BLOCKS", {
        get: function () { return this.native.ACTIVE_UNIFORM_BLOCKS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_TYPE", {
        get: function () { return this.native.UNIFORM_TYPE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_SIZE", {
        get: function () { return this.native.UNIFORM_SIZE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_BLOCK_INDEX", {
        get: function () { return this.native.UNIFORM_BLOCK_INDEX; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_OFFSET", {
        get: function () { return this.native.UNIFORM_OFFSET; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_ARRAY_STRIDE", {
        get: function () { return this.native.UNIFORM_ARRAY_STRIDE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_MATRIX_STRIDE", {
        get: function () { return this.native.UNIFORM_MATRIX_STRIDE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_IS_ROW_MAJOR", {
        get: function () { return this.native.UNIFORM_IS_ROW_MAJOR; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_BLOCK_BINDING", {
        get: function () { return this.native.UNIFORM_BLOCK_BINDING; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_BLOCK_DATA_SIZE", {
        get: function () { return this.native.UNIFORM_BLOCK_DATA_SIZE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_BLOCK_ACTIVE_UNIFORMS", {
        get: function () { return this.native.UNIFORM_BLOCK_ACTIVE_UNIFORMS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES", {
        get: function () { return this.native.UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER", {
        get: function () { return this.native.UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER", {
        get: function () { return this.native.UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "OBJECT_TYPE", {
        get: function () { return this.native.OBJECT_TYPE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SYNC_CONDITION", {
        get: function () { return this.native.SYNC_CONDITION; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SYNC_STATUS", {
        get: function () { return this.native.SYNC_STATUS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SYNC_FLAGS", {
        get: function () { return this.native.SYNC_FLAGS; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SYNC_FENCE", {
        get: function () { return this.native.SYNC_FENCE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SYNC_GPU_COMMANDS_COMPLETE", {
        get: function () { return this.native.SYNC_GPU_COMMANDS_COMPLETE; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "UNSIGNALED", {
        get: function () { return this.native.UNSIGNALED; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SIGNALED", {
        get: function () { return this.native.SIGNALED; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "ALREADY_SIGNALED", {
        get: function () { return this.native.ALREADY_SIGNALED; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TIMEOUT_EXPIRED", {
        get: function () { return this.native.TIMEOUT_EXPIRED; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "CONDITION_SATISFIED", {
        get: function () { return this.native.CONDITION_SATISFIED; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "WAIT_FAILED", {
        get: function () { return this.native.WAIT_FAILED; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "SYNC_FLUSH_COMMANDS_BIT", {
        get: function () { return this.native.SYNC_FLUSH_COMMANDS_BIT; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "COLOR", {
        get: function () { return this.native.COLOR; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DEPTH", {
        get: function () { return this.native.DEPTH; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "STENCIL", {
        get: function () { return this.native.STENCIL; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MIN", {
        get: function () { return this.native.MIN; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX", {
        get: function () { return this.native.MAX; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DEPTH_COMPONENT24", {
        get: function () { return this.native.DEPTH_COMPONENT24; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "STREAM_READ", {
        get: function () { return this.native.STREAM_READ; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "STREAM_COPY", {
        get: function () { return this.native.STREAM_COPY; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "STATIC_READ", {
        get: function () { return this.native.STATIC_READ; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "STATIC_COPY", {
        get: function () { return this.native.STATIC_COPY; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DYNAMIC_READ", {
        get: function () { return this.native.DYNAMIC_READ; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DYNAMIC_COPY", {
        get: function () { return this.native.DYNAMIC_COPY; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DEPTH_COMPONENT32F", {
        get: function () { return this.native.DEPTH_COMPONENT32F; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "DEPTH32F_STENCIL8", {
        get: function () { return this.native.DEPTH32F_STENCIL8; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "INVALID_INDEX", {
        get: function () { return this.native.INVALID_INDEX; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "TIMEOUT_IGNORED", {
        get: function () { return this.native.TIMEOUT_IGNORED; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSWebGL2RenderingContext.prototype, "MAX_CLIENT_WAIT_TIMEOUT_WEBGL", {
        get: function () { return this.native.MAX_CLIENT_WAIT_TIMEOUT_WEBGL; },
        enumerable: true,
        configurable: true
    });
    TNSWebGL2RenderingContext.isDebug = false;
    return TNSWebGL2RenderingContext;
}(TNSWebGLRenderingContext_1.TNSWebGLRenderingContext));
exports.TNSWebGL2RenderingContext = TNSWebGL2RenderingContext;
//# sourceMappingURL=TNSWebGL2RenderingContext.android.js.map